#
# spec file for package python-avocado-plugins-vt
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pythons python3
Name:           python-avocado-plugins-vt
Version:        88.0
Release:        2.1
Summary:        Avocado Virt Test Plugin
License:        GPL-2.0-only
URL:            https://avocado-framework.readthedocs.org/
Source0:        https://github.com/avocado-framework/avocado-vt/archive/%{version}.tar.gz#/avocado-vt-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       attr
Requires:       bridge-utils
# Requires:     autotest-framework
Requires:       gcc
Requires:       git-core
Requires:       glibc-devel
Requires:       iproute
Requires:       iputils
Requires:       make
Requires:       netcat-openbsd
Requires:       openvswitch
Requires:       python-aexpect > 1.5.0
Requires:       python-avocado >= 68.0
Requires:       python-netaddr >= 0.7.18
Requires:       python-netifaces >= 0.10.5
Requires:       python-simplejson >= 3.5.3
Requires:       python-six
Requires:       qemu-kvm
Requires:       systemtap
Requires:       tcpdump
Requires:       xz
Recommends:     libvirt
Recommends:     policycoreutils-python
BuildArch:      noarch
%ifpython2
Requires:       python-devel
%else
Requires:       python3-dbm
Requires:       python3-devel
%endif
%python_subpackages

%description
Avocado Virt Test is a plugin that executes virt-tests with all the avocado
features, such as HTML report and Xunit output, among others.

%prep
%setup -q -n avocado-vt-%{version}
sed -E -i "1{s|^#\!\s*/usr/bin/env python$|#\!%{_bindir}/python3|}" \
    scripts/*py \
    scripts/github/*py \
    virttest/remote_commander/*py \
    virttest/shared/deps/run_autotest/boottool.py
sed -E -i "1s/env //" virttest/shared/scripts/pmsocat/pmsocat36.py
sed -E -i "1s|^(#\!/usr/bin/python)$|\13|" \
    virttest/*py \
    virttest/shared/deps/serial/*py \
    virttest/shared/scripts/*py \
    virttest/staging/*py

%build
%pyproject_wheel

%install
%pyproject_install

# Reduce duplicities
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%fdupes %{buildroot}%{_datadir}/avocado-plugins-vt

%files %{python_files}
%license LICENSE
%doc README.rst
%config(noreplace)%{python_sitelib}/avocado_vt/conf.d/vt.conf
%config(noreplace)%{python_sitelib}/avocado_vt/conf.d/vt_joblock.conf
%{python_sitelib}/avocado_vt
%{python_sitelib}/virttest
%{python_sitelib}/avocado_framework_plugin_vt-%{version}.dist-info

%changelog
* Wed Jun  4 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
- Tidy up %%files.
* Thu Jun 24 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to version 88:
  * No upstream changelog
- Remove common package, upstream now require configuration and backends
  in the python purelib directory.
- Update BuildRequires/Requires
- Force all scripts to execute python3
- Switch fdupes macro to using hardlinks
* Fri May 28 2021 Steve Kowalik <steven.kowalik@suse.com>
- Convert to single-spec, like its dependencies avocado and aexpect.
* Fri Mar  1 2019 Jozef Pupava <jpupava@suse.com>
- Update to version 69
  * No upstream changelog available
- Add make dependency, needed for following tests:
  * type_specific.io
  * github-autotest-qemu.qemu_cpu.cpuid.custom.vendor.normal.kvm.
  * cpu_model_unset.host_cpu_vendor_unknown.qemu_flavor_unknown
* Mon Feb 25 2019 Jozef Pupava <jpupava@suse.com>
- Update package dependencies
* Mon Nov  5 2018 Martin Pluskal <mpluskal@suse.com>
- Update package dependencies
* Tue Sep 11 2018 Jan Engelhardt <jengelh@inai.de>
- Update RPM groups. Update description grammar.
* Mon Jul 30 2018 mpluskal@suse.com
- Initial changelog entry
